@@ -68,15 +68,15 @@
 #' # Dataset, location and datatype for PRECIP_HLY data
 #' ncdc(datasetid='PRECIP_HLY', locationid='ZIP:28801', datatypeid='HPCP',
 #'    startdate = '2010-05-01', enddate = '2010-05-10')
-#' 
+#'
 #' # multiple datatypeid's
 #' ncdc(datasetid='PRECIP_HLY', datatypeid=c('HPCP', 'ACMC'),
-#'    startdate = '2010-05-01', enddate = '2010-05-10')   
-#'    
+#'    startdate = '2010-05-01', enddate = '2010-05-10')
+#'
 #' # multiple locationid's
 #' ncdc(datasetid='PRECIP_HLY', locationid=c("FIPS:30103", "FIPS:30091"),
 #'    startdate = '2010-05-01', enddate = '2010-05-10')
-#' 
+#'
 #' # Dataset, location, station and datatype
 #' ncdc(datasetid='PRECIP_HLY', locationid='ZIP:28801', stationid='COOP:310301', datatypeid='HPCP',
 #'    startdate = '2010-05-01', enddate = '2010-05-10')
@@ -117,13 +117,13 @@
 #'    enddate = '2013-12-01')
 #' ncdc(datasetid='GHCND', stationid='GHCND:USW00014895', startdate = '2013-10-01',
 #'    enddate = '2013-12-01', includemetadata=FALSE)
-#'    
+#'
 #' # Many stationid's
 #' stat <- ncdc_stations(startdate = "2000-01-01", enddate = "2016-01-01")
 #' ## find out what datasets might be available for these stations
 #' ncdc_datasets(stationid = stat$data$id[1])
 #' ## get some data
-#' ncdc(datasetid = "ANNUAL", stationid = stat$data$id[1:10], 
+#' ncdc(datasetid = "ANNUAL", stationid = stat$data$id[1:10],
 #'    startdate = "2010-01-01", enddate = "2011-01-01")
 #' }
 #'
@@ -164,7 +164,7 @@ ncdc <- function(datasetid=NULL, datatypeid=NULL, stationid=NULL, locationid=NUL
   if (length(args) == 0) args <- NULL
   temp <- GET(base, query=args, add_headers("token" = token), ...)
   tt <- check_response(temp)
-  if(is(tt, "character")){
+  if(inherits(tt, "character")){
     all <- list(meta=NA, data=NA)
   } else {
     tt$results <- lapply(tt$results, split_atts, ds=datasetid)
