@@ -54,14 +54,14 @@ seaiceeurls <- function(yr=NULL, mo=NULL, pole=NULL) {
   months_prevyr <- c(paste0(0, seq(1, 9)), c(10, 11, 12))
   yrs_months <- do.call(c, lapply(yrs_prev, function(x) paste(x, months_prevyr, sep = '')))
   urls <- do.call(c, lapply(c('S', 'N'), function(x) {
-    paste(eachmonth, 'extent_', x, '_', yrs_months, '_polygon.zip', sep = '')
+    paste(eachmonth, 'extent_', x, '_', yrs_months, '_polygon_v2.zip', sep = '')
   }))
 
   months_thisyr <- paste0(0, seq(1,month(today())))
   yrs_months_thisyr <- paste0(2013, months_thisyr)
   eachmonth_thiyr <- eachmonth[1:grep(month(today() - months(1), label = TRUE, abbr = TRUE), eachmonth)]
   urls_thisyr <- do.call(c, lapply(c('S', 'N'), function(x) {
-    paste(eachmonth_thiyr, 'extent_', x, '_', yrs_months_thisyr, '_polygon.zip', sep = '')
+    paste(eachmonth_thiyr, 'extent_', x, '_', yrs_months_thisyr, '_polygon_v2.zip', sep = '')
   }))
 
   allurls <- c(urls, urls_thisyr)
